@@ -8,6 +8,7 @@
 #include "SDFShader.h"
 
 #include <QOpenGLContext>
+#include <QSurfaceFormat>
 
 static const char shaderRoot[] = ":/org.kde.quickcharts/";
 
@@ -21,13 +22,17 @@ SDFShader::~SDFShader()
 
 void SDFShader::setShaders(const QString &vertex, const QString &fragment)
 {
-    auto header = QOpenGLContext::currentContext()->isOpenGLES() ? QStringLiteral("es_header.glsl") : QStringLiteral("desktop_header.glsl");
+    auto header = QStringLiteral("header_desktop.glsl");
+    auto format = QOpenGLContext::currentContext()->format();
+    if (format.renderableType() == QSurfaceFormat::OpenGLES) {
+        header = QStringLiteral("header_es2.glsl");
+    }
 
     setShaderSourceFiles(QOpenGLShader::Vertex, {QString::fromLatin1(shaderRoot) + header, QString::fromLatin1(shaderRoot) + vertex});
 
     setShaderSourceFiles(
         QOpenGLShader::Fragment,
         {QString::fromLatin1(shaderRoot) + header,
-         QString::fromLatin1(shaderRoot) + QStringLiteral("sdf.frag"),
+         QString::fromLatin1(shaderRoot) + QStringLiteral("sdf.glsl"),
          QString::fromLatin1(shaderRoot) + fragment});
 }
